import requests

from .endpoints.extract import Extract
from .endpoints.embed import Embed
from .endpoints.generate import Generate
from .endpoints.connections import Connections
from .endpoints.tools import Tools
from .endpoints.pipelines import Pipelines


class Mixpeek:
    def __init__(self, api_key: str):
        self.api_key = api_key
        self.base_url = "http://localhost:8000/"
        self.headers = {
            "Authorization": f"Bearer {self.api_key}",
            "Content-Type": "application/json"
        }
        self.extract = Extract(self.base_url, self.headers)
        self.embed = Embed(self.base_url, self.headers)
        self.generate = Generate(self.base_url, self.headers)
        self.connections = Connections(self.base_url, self.headers)
        self.tools = Tools(self.base_url, self.headers)
        self.pipelines = Pipelines(self.base_url, self.headers)



import requests
from pydantic import BaseModel

class Generate:
    def __init__(self, base_url, headers):
        self.base_url = base_url
        self.headers = headers

    def text(self, model_id: str, response_format: BaseModel, context: str):
        url = f"{self.base_url}generate/text"
        data = {
            "model_id": model_id,
            "response_format": response_format.schema_json(),  # Ensure correct method to get JSON schema
            "context": context
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()


class MixpeekException(Exception):
    pass

class AuthenticationError(MixpeekException):
    pass

class BadRequestError(MixpeekException):
    pass

class NotFoundError(MixpeekException):
    pass

# Define more exceptions as needed



import requests

class Extract:
    def __init__(self, base_url, headers):
        self.base_url = base_url
        self.headers = headers

    def extract(self, modality: str, input: str, input_type: str):
        url = f"{self.base_url}extract/"
        data = {
            "modality": modality,
            "input": input,
            "input_type": input_type
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()



import requests

class Connections:
    def __init__(self, base_url, headers):
        self.base_url = base_url
        self.headers = headers
        self.data = self.Data(self)

    def create(self, alias: str, engine: str, details: dict):
        url = f"{self.base_url}connections/"
        data = {
            "alias": alias,
            "engine": engine,
            "details": details
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    # mixpeek.connections.data.insert(connection_id="123", payload={"key": "value"})
    class Data:
        def __init__(self, parent):
            self.base_url = parent.base_url
            self.headers = parent.headers
        
        def insert(self, connection_id: str, payload: list):
            pass

        def delete(self, connection_id: str, filters: dict):
            pass
            
        



import requests

class Pipelines:
    def __init__(self, base_url, headers):
        self.base_url = base_url
        self.headers = headers

    # mixpeek.pipelines.enable
    def enable(self, pipeline_id: str, enable: bool):
        url = f"{self.base_url}pipelines/{pipeline_id}/enable"
        data = {
            "enable": enable
        }
        response = requests.patch(url, json=data, headers=self.headers)
        return response.json()

    # mixpeek.pipelines.create
    def create(self, alias: str, code: str, destination: dict, source: dict):
        url = f"{self.base_url}pipelines/"
        data = {
            "alias": alias,
            "code": code,
            "destination": destination,
            "source": source
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    # mixpeek.pipelines.invoke
    def invoke(self, pipeline_id: str, payload: dict, options: dict):
        url = f"{self.base_url}pipelines/invoke/{pipeline_id}"
        data = {
            "payload": payload,
            "options": options
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()


import requests
from magika import Magika


modality_to_content_types = {
    "text": [
        "application/pdf",
        "text/html",
        "text/html; charset=utf-8",
        "text/csv",
        "text/plain",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
        "application/vnd.ms-powerpoint",
        "application/vnd.openxmlformats-officedocument.presentationml.presentation",
        "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
        "text/plain",
        "text/markdown",
        "application/xml",
    ],
    "image": [
        "image/png",
        "image/jpeg",
        "image/gif",
        "image/bmp",
        "image/tiff",
        "image/webp",
    ],
    "audio": [
        "audio/mpeg",
        "audio/wav",
        "audio/ogg",
        "audio/flac",
        "audio/mp4",
        "audio/aac",
        "audio/mp3",
    ],
    "video": [
        "video/mp4",
        "video/x-msvideo",
        "video/quicktime",
        "video/x-ms-wmv",
        "video/x-flv",
    ],
}



class Tools:
    def __init__(self, base_url, headers):
        self.base_url = base_url
        self.headers = headers
        self.video = self.Video(self)

    def detect(self, url: str):
        # Fetch the file from the URL
        response = requests.get(url)
        content_type = response.headers.get('Content-Type', '').split(';')[0]  # Get the base MIME type without parameters

        # Determine modality based on MIME type and Magika detection
        for modality, types in modality_to_content_types.items():
            if content_type in types:
                return modality
        return 'unknown'

    class Video:
        def __init__(self, parent):
            self.base_url = parent.base_url
            self.headers = parent.headers

        def process(self, url: str, frame_interval: int, resolution: list, return_base64: bool):
            endpoint = f"{self.base_url}tools/video/process"
            data = {
                "url": url,
                "frame_interval": frame_interval,
                "resolution": resolution,
                "return_base64": return_base64
            }
            response = requests.post(endpoint, json=data, headers=self.headers)
            return response.json()


from setuptools import setup, find_packages

# Read the contents of your requirements.txt file
with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    name='mixpeek',
    version='0.6.25',
    author='Ethan Steininger',
    author_email='ethan@mixpeek.com',
    description='Mixpeek Python SDK',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/mixpeek/mixpeek-python',
    packages=find_packages(),
    install_requires=required,
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)



import requests

class Embed:
    def __init__(self, base_url, headers):
        self.base_url = base_url
        self.headers = headers

    def video(self, model_id: str, input: str, input_type: str):
        url = f"{self.base_url}embed/"
        data = {
            "modality": "video",
            "model_id": model_id,
            "input": input,
            "input_type": input_type
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    def text(self, model_id: str, input: str, input_type: str):
        url = f"{self.base_url}embed/"
        data = {
            "modality": "text",
            "model_id": model_id,
            "input": input,
            "input_type": input_type
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    def image(self, model_id: str, input: str, input_type: str):
        url = f"{self.base_url}embed/"
        data = {
            "modality": "image",
            "model_id": model_id,
            "input": input,
            "input_type": input_type
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    def audio(self, model_id: str, input: str, input_type: str):
        url = f"{self.base_url}embed/"
        data = {
            "modality": "audio",
            "model_id": model_id,
            "input": input,
            "input_type": input_type
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()